#include "globals.h"

#define TR_START "    <tr>\n        "
#define TR_END   "\n    </tr>\n"

/**
 * Write <td>field</td> to the pipe.
 * @param field the field contents.
 * @param fd array of pipe file ids.
 */
void write_td(char *field, int fd[]);

/**
 * Read the CSV data from stdin and write
 * its lines as HTML rows to the pipe.
 * @param fd array of pipe file ids.
 * @param pid the child process id.
 */
void parent(int fd[],  pid_t pid)
{
    size_t n = BUFFER_SIZE;
    char *field = malloc(n);

    // Close the unused READ end of the pipe.
    close(fd[READ_FD]);

    // Loop to read the fields of each input line from stdin.
    while (getdelim(&field, &n, ',', stdin) >= 0)
    {
        // Write <tr> then the first field to the pipe.
        write(fd[WRITE_FD], TR_START, strlen(TR_START));
        write_td(field, fd);

        // Write subsequent fields up to the last field to the pipe.
        for (int i = 2; i < FIELD_COUNT; i++)
        {
            getdelim(&field, &n, ',', stdin);
            write_td(field, fd);
        }

        // Write the last field followed by </tr> to the pipe.
        getline(&field, &n, stdin);
        write_td(field, fd);
        write(fd[WRITE_FD], TR_END, strlen(TR_END));
    }

    free(field);

    // Wait for the child process to finish.
    int status;
    waitpid(pid, &status, 0);

    // Close the WRITE end of the pipe.
    close(fd[WRITE_FD]);
}

void write_td(char *field, int fd[])
{
    char td[BUFFER_SIZE];

    // Remove the , or \n delimiter.
    field[strlen(field) - 1] = '\0';

    // Write <td>field</td> the pipe.
    sprintf(td, "<td>%s</td>", field);
    write(fd[WRITE_FD], td, strlen(td));
}
